send_exception

Function send_exception 

pub async fn send_exception<S: AsyncStream + Unpin>(
    stream: &mut S,
    question_identifier: u32,
    reason: &str,
) -> Result<(), RpcError>
Replies to a call with an unimplemented exception, mirroring what capnp-go sends when a server does not implement a method.